@@ -5,7 +5,7 @@ use Getopt::Long qw/GetOptionsFromArray/;
 use POSIX qw/strftime/;
 use Config::CmdRC qw/.from_unixtimerc/;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our $MAYBE_UNIXTIME = join '|', (
     'created_(?:at|on)',
@@ -32,34 +32,33 @@ sub _main {
 
     while ( my $line = <STDIN> ) {
         chomp $line;
-        if ($line =~ m!(?:$MAYBE_UNIXTIME)!
-                || ($config->{_re} && $line =~ m!(?:$config->{_re})!) ) {
-            $line =~ s/(\d+)/&_from_unixtime($1, $config)/eg;
+        if ($line =~ m!(?:$MAYBE_UNIXTIME)[^\d]*(\d+)!
+                || ($config->{_re} && $line =~ m!(?:$config->{_re})[^\d]*(\d+)!)
+                || $line =~ m!^[\s\t\r\n]*(\d+)[\s\t\r\n]*$!
+        ) {
+            _from_unixtime($1 => \$line, $config);
         }
         print "$line\n";
     }
 }
 
 sub _from_unixtime {
-    my ($maybe_unixtime, $config) = @_;
+    my ($maybe_unixtime, $line_ref, $config) = @_;
 
     if ($maybe_unixtime > 2**31-1) {
-        return $maybe_unixtime;
+        return;
     }
 
-    my $date = eval { strftime($config->{format}, localtime($maybe_unixtime)) };
-    if ($@) {
-        return $maybe_unixtime;
-    }
-    else {
-        return sprintf(
-            "%s%s%s%s",
-            $maybe_unixtime,
-            $config->{'start-bracket'},
-            $date,
-            $config->{'end-bracket'},
-        );
-    }
+    my $date = strftime($config->{format}, localtime($maybe_unixtime));
+    my $replaced_unixtime = sprintf(
+        "%s%s%s%s",
+        $maybe_unixtime,
+        $config->{'start-bracket'},
+        $date,
+        $config->{'end-bracket'},
+    );
+
+    $$line_ref =~ s/$maybe_unixtime/$replaced_unixtime/;
 }
 
 sub _merge_opt {
